@@ -3,34 +3,43 @@
 """Igloo: a command line pastebin client.
 
 Usage:
-  igloo [-t TITLE] [-s SYNTAX] [-p PRIVACY] [-e EXPIRATION] [-f FILE]
+  igloo [-t TITLE] [-s SYNTAX] [-p PRIVACY] [-e EXPIRATION] [FILE] ...
   igloo (-l | --list)
+  igloo (-r | --reset)
   igloo (-h | --help)
   igloo --version
 
 Examples:
-  igloo -s python -f my_code.py
-  igloo -t 'vimrc copy' -s vim -p private < .vimrc
+  igloo my_file.txt
+  igloo -t 'code snippet' -s python -p private < my_code.py
   echo 'hello world!' | igloo
 
+Arguments:
+  FILE                                    File(s) to copy. Multiple files will
+                                          have their contents joined by
+                                          newlines. If no file is specified
+                                          standard input will be used instead.
+
 Options:
   -h --help                               Show this screen.
   --version                               Show version.
-  -l --list                               View list of snippets.
   -t TITLE --title=TITLE                  Title of snippet.
   -s SYNTAX --syntax=SYNTAX               Highlighting format.
   -p PRIVACY --privacy=PRIVACY            Privacy level [default: unlisted].
   -e EXPIRATION --expiration=EXPIRATION   Lifetime of snippet [default: 1H].
-  -f FILE --file=FILE                     File to copy. Standard input will be
-                                          used if no file is specified.
+  -l --list                               View list of snippets by the current
+                                          logged in user.
+  -r --reset                              Reset pastebin credentials.
 
 """
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 
 
 from getpass import getpass
 from json import dump, load
+from os import remove
+from os.path import abspath
 from sys import stdin
 
 try:
@@ -49,38 +58,47 @@ class PasteError(Exception):
 
 class Client(object):
 
-  def __init__(self, key_storage_path='key.json'):
-    self.session = Session()
-    self.key = self._get_key(key_storage_path)
+  key_storage_path = 'key.json'
 
-  def _get_key(self, key_storage_path):
-    try:
-      with open(key_storage_path) as f:
-        key = load(f)
-    except IOError:
+  _key = None
+
+  def __init__(self):
+    self.session = Session()
+
+  @property
+  def key(self):
+    if self._key is None:
       try:
-        api_dev_key = raw_input('API dev key: ')
-        req = self.session.post(
-          'http://pastebin.com/api/api_login.php',
-          data={
+        with open(self.key_storage_path) as f:
+          key = load(f)
+      except IOError:
+        try:
+          api_dev_key = raw_input('API dev key: ')
+          req = self.session.post(
+            'http://pastebin.com/api/api_login.php',
+            data={
+              'api_dev_key': api_dev_key,
+              'api_user_name': raw_input('API user name: '),
+              'api_user_password': getpass('API user password: '),
+            }
+          )
+        except Timeout:
+          raise PasteError('Unable to connect to server.')
+        else:
+          if 'Bad API request' in req.content:
+            raise PasteError(req.content)
+          key = {
             'api_dev_key': api_dev_key,
-            'api_user_name': raw_input('API user name: '),
-            'api_user_password': getpass('API user password: '),
+            'api_user_key': req.content,
           }
-        )
-      except Timeout:
-        raise PasteError('Unable to connect to server.')
-      else:
-        if 'Bad API request' in req.content:
-          raise PasteError(req.content)
-        key = {
-          'api_dev_key': api_dev_key,
-          'api_user_key': req.content,
-        }
-        with open(key_storage_path, 'w') as g:
-          dump(key, g)
-          print 'API keys stored in %r.' % (key_storage_path, )
-    return key
+          with open(self.key_storage_path, 'w') as g:
+            dump(key, g)
+          print (
+            'Pastebin credentials stored in %r.' %
+            (abspath(self.key_storage_path), )
+          )
+      self._key = key
+    return self._key
 
   def _get_response(self, data):
     response = self.session.send(
@@ -121,21 +139,36 @@ class Client(object):
       data['api_paste_expire_date'] = expiration
     if syntax:
       data['api_paste_format'] = syntax
-    return self._get_response(data)
+    url = self._get_response(data)
+    print 'Pastebin created! Url: %s' % (url, )
 
   def view_list_of_pastes(self):
     print self._get_response({'api_option': 'list'})
 
+  def reset_credentials(self):
+    try:
+      remove(self.key_storage_path)
+    except OSError:
+      print 'No credentials to delete.'
+    else:
+      print 'Credentials deleted.'
+
+
 def main():
   arguments = docopt(__doc__, version=__version__)
   client = Client()
-  if arguments['--list']:
+  if arguments['--reset']:
+    client.reset_credentials()
+  elif arguments['--list']:
     client.view_list_of_pastes()
   else:
-    filepath = arguments['--file']
-    if filepath:
-      with open(filepath) as f:
-        content = f.read()
+    filepaths = arguments['FILE']
+    if filepaths:
+      contents = []
+      for filepath in filepaths:
+        with open(filepath) as f:
+          contents.append(f.read())
+      content = '\n\n'.join(contents)
     else:
       content = stdin.read()
     url = client.create_paste(
@@ -145,7 +178,6 @@ def main():
       privacy=arguments['--privacy'],
       expiration=arguments['--expiration']
     )
-    print 'Pastebin created! Url: %s' % (url, )
 
 if __name__ == '__main__':
   main()
